<?php
/**
 *  @file
 *  Theme & preprocess functions for the Views jQFX: Imageflow module.
 */

/**
 *  We'll grab only the first image from each row.
 */
function template_preprocess_views_jqfx_imageflow(&$vars) {
  // Initialize our $images array.
  $vars['images'] = array();

  // Strip all images from the $rows created by the original view query.
  foreach ($vars['rows'] as $item) {
    if (preg_match('@(<\s*img\s+[^>]*>)@i', $item, $matches)) {
      $image = $matches[1];
      // We need to add a URL to 'longdesc', as required by the plugin.
      // If our image is in an anchor tag, use its URL.
      if (preg_match('@<\s*a\s+href\s*=\s*"\s*([^"]+)\s*"[^>]*>[^<]*' . preg_quote($image) . '[^<]*<\s*/a\s*>@i', $item, $urls)) {
        $url = $urls[1];
      }
      // Or look to see if we have any other links in our views items.
      elseif (preg_match('@href\s*=\s*"([^"]+)"@i', $item, $urls)) {
        $url = $urls[1];
      }
      // Otherwise link to the original image.
      elseif (preg_match('@src\s*=\s*"([^"]+)"@i', $image, $urls)) {
        $url = $urls[1];
      }
      else {$url = url('<front>');}

      // Add the URL to the image's longdesc tag.
      $image = preg_replace('@img\s+@i', 'img longdesc="' . $url . '" ', $image);

      // Remove the base url from the image path for the reflect script.
      $image = str_replace(array('http://' . $_SERVER['HTTP_HOST'], 'https://' . $_SERVER['HTTP_HOST']), '', $image);

      // Add the image to our image array to display.
      $vars['images'][] = $image;
    }
  }

  $options = $vars['options']['views_jqfx_imageflow'];

  // Pass our background and text colors to the template.
  if (($options['background_color']) || ($options['text_color'])) {
    $vars['styles'] = 'style="background-color:' . $options['background_color'] . ';color:' . $options['text_color'] . ';"';
  }
  else $vars['styles'] = NULL;

  _views_jqfx_imageflow_add_js($options, 'views-jqfx-imageflow-images-' . $vars['id']);
}

function _views_jqfx_imageflow_add_js($options, $id) {

  // Add the plugin JS and CSS.
  $plugin_path = libraries_get_path('ImageFlow');
  drupal_add_js($plugin_path . '/imageflow.js');
  drupal_add_css($plugin_path . '/imageflow.css');

  //Add the module JS and CSS
  $module_path = drupal_get_path('module', 'views_jqfx_imageflow');
  drupal_add_js($module_path . '/js/views_jqfx_imageflow.js');
  drupal_add_css($module_path . '/css/views_jqfx_imageflow.css');

  $settings = array(
    'ImageFlowID'       => $id,
    'aspectRatio'       => (float) $options['aspect_ratio'],
    'imagePath'         => '../../../..',
    'reflectPath'       => '/' . $plugin_path . '/',
    // Navigation
    'buttons'           => (bool) $options['nav']['buttons'],
    'captions'          => (bool) $options['nav']['captions'],
    'imageCursor'       => $options['nav']['image_cursor'],
    'scrollbarP'        => (float) $options['nav']['scroll']['scrollbar_p'],
    'slider'            => (bool) $options['nav']['scroll']['slider'],
    'sliderCursor'      => $options['nav']['scroll']['slider_cursor'],
    'sliderWidth'       => (int) $options['nav']['scroll']['slider_width'],
    // Image
    'imageFocusM'       => (float) $options['img']['image_focus_m'],
    'imageFocusMax'     => (int) $options['img']['image_focus_max'],
    'imageScaling'      => (bool) $options['img']['image_scaling'],
    'imagesHeight'      => (float) $options['img']['images_height'],
    'imagesM'           => (float) $options['img']['images_m'],
    'opacity'           => (bool) $options['img']['opacity'],
    'percentLandscape'  => (int) $options['img']['percent_landscape'],
    'percentOther'      => (int) $options['img']['percent_other'],
    'preloadImages'     => (bool) $options['img']['preload_images'],
    'xStep'             => (int) $options['img']['x_step'],
    'reflections'       => (bool) $options['img']['refl']['reflections'],
    'reflectionPNG'     => (bool) $options['img']['refl']['reflection_png'],
    // Animation
    'animationSpeed'    => (int) $options['anime']['animation_speed'],
    'circular'          => (bool) $options['anime']['circular'],
    'glideToStartID'    => (bool) $options['anime']['glide_to_start_id'],
    'slideshow'         => (bool) $options['anime']['slideshow'],
    'slideshowAutoplay' => (bool) $options['anime']['slideshow_autoplay'],
    'slideshowSpeed'    => (int) $options['anime']['slideshow_speed'],
    'startID'           => (int) $options['anime']['start_id'],
    'startAnimation'    => (bool) $options['anime']['start_animation'],
  );

  // These can break imageflow if passed empty.
  if ($options['img']['opacity_array']) {
    $settings['opacityArray'] = check_plain($options['img']['opacity_array']);
  }
  if ($options['img']['refl']['reflection_get']) {
    $settings['reflectionGET'] = $options['img']['refl']['reflection_get'];
  }
  if ($options['img']['reflection_p']) {
    $settings['reflectionP'] = (float)$options['img']['reflection_p'];
  }
  if ($options['on_click']) {
    $settings['onClick'] = $options['on_click'];
  }

  drupal_add_js(array('viewsJqfxImageFlow' => array($id => $settings)), 'setting');
}
